@@ -5,12 +5,14 @@
 #' @param \dots The data paremeters.
 #' @param prop \code{c('row', 'col')} if 'col' column proportions will be
 #' computed; the default is 'row' proportions.
+#' @param tests A logical whether association tests should be shown below table; default is \code{FALSE}.
 #' @param deparse.level Integer controlling the construction of labels in the case of non-matrix-like arguments. If 0, middle 2 rownames, if 1, 3 rownames, if 2, 4 rownames (default).
 #' @keywords Tables Stats
 #'
 #' @return A cross tabulated object. Also can genarate the as latex.
 #' @examples
 #' crosstable(titanic, SEX, AGE)
+#'
 #'  titanic %>% tab(SEX, AGE, SURVIVED)
 #'
 #' # Agresti (2002), table 3.11, p. 106
@@ -43,7 +45,7 @@
 #' @keywords Tables Descriptive
 #' @export
 #' @rdname tab
-crosstable <- function(.data, ..., prop="row", deparse.level = 2){
+crosstable <- function(.data, ..., prop="row", tests=FALSE, deparse.level = 2){
   #################################################################
   #                                                               #
   # Function created by Daniel Marcelino                          #
@@ -311,4 +313,3 @@ NULL
   crosstable(..., deparse.level = 2)
 }
 NULL
-
