@@ -1,6 +1,6 @@
 #' @title Method D'Hondt
 #' @description The function calculate the seats allotment in legislative house, given the total number of seats and the votes for each party based on the Victor D'Hondt's method (1878), which is mathematically equivalent to the method proposed by Thomas Jefferson few years before (1792).
-#' @param parties A vector containig the identification of parties or candidates accordingly to the election outcome.
+#' @param parties A vector containig parties labels or candidates accordingly to the \code{votes} vector order.
 #' @param votes A vector containing the total number of formal votes received by the parties/candidates.
 #' @param seats An integer for the number of seats to be filled (the district magnitude).
 #' @author Daniel Marcelino, \email{dmarcelino@@live.com}.
@@ -8,7 +8,9 @@
 #' @export
 #' @examples
 #' votes <- sample(1:10000, 5)
-#' dHondt(letters[1:5], votes, 5 )
+#' parties <- sample(letters, 5)
+#' dHondt(parties, votes, 5 )
+#'
 #'
 #' # Example: 2014 Brazilian election for the lower house in the state of Ceara.
 #' # Coalitions leading by the following parties:
@@ -34,7 +36,7 @@
      1:seats ))
   );
   out <- with(.temp, (parties[order(-scores)][1:seats]))
-   out <- data.frame(freq(out)[,1:3]);
+   out <- data.frame(SciencesPo::freq(out)[,1:3]);
    out  <- out %>% dplyr::arrange(dplyr::desc(freq));
    names(out) <-c("Parties", "d'Hondt", "Perc");
      return(out)
